@@ -70,6 +70,13 @@ testthat::test_that("Partial inbreeding", {
   arrui_Fij_custom_2cores <- purgeR::ip_Fij(arrui50, mode = "custom", ancestors =  anc, ncores = 2)
   testthat::expect_equal(arrui_Fij_custom, arrui_Fij_custom_2cores, tolerance = 1e-5, check.attributes = FALSE)
   testthat::expect_equal(base::dim(arrui_Fij_custom), base::dim(arrui_Fij_custom_2cores))
+  atlas_Fij_genedrop <- purgeR::ip_Fij(atlas50, genedrop = 1000, seed = 1234)
+  testthat::expect_equal(atlas_Fij_genedrop[[50, 1]], 0.183, tolerance = 1e-5)
+  testthat::expect_equal(atlas_Fij_genedrop[[50, 2]], 0.0, tolerance = 1e-5)
+  testthat::expect_equal(atlas_Fij_genedrop[[48, 1]], 0.128, tolerance = 1e-5)
+  testthat::expect_equal(atlas_Fij_genedrop[[48, 2]], 0.107, tolerance = 1e-5)
+  testthat::expect_equal(base::sum(atlas_Fij_genedrop[,1]), 4.341, tolerance = 1e-5)
+  testthat::expect_equal(base::sum(atlas_Fij_genedrop[,2]), 1.807, tolerance = 1e-5)
 })
 
 testthat::test_that("Purged inbreeding", {
@@ -101,16 +108,15 @@ testthat::test_that("Opportunity of purging", {
   testthat::expect_equal(base::sum(gulisija$O), 0.5625, tolerance = 1e-5)
   testthat::expect_equal(gulisija$Oe[9], 0.0625, tolerance = 1e-5)
   testthat::expect_equal(base::sum(gulisija$Oe), 0.0625, tolerance = 1e-5)
-  arrui_op_fix <- ip_op(arrui, compute_O = TRUE)
-  arrui_op_raw <- ip_op(arrui, complex = FALSE, compute_O = TRUE)
-  testthat::expect_equal(sum(arrui_op_fix$O), 259.3293, tolerance = 1e-5)
-  testthat::expect_equal(sum(arrui_op_raw$O), 310.843, tolerance = 1e-5)
-  testthat::expect_equal(sum(arrui_op_fix$Oe), 31.44434, tolerance = 1e-5)
-  testthat::expect_equal(sum(arrui_op_raw$Oe), 34.47632, tolerance = 1e-5)
-  testthat::expect_equal(arrui_op_fix[370, ]$O, 1.169922, tolerance = 1e-5)
-  testthat::expect_equal(arrui_op_raw[370, ]$O, 2.029297, tolerance = 1e-5)
-  testthat::expect_equal(arrui_op_fix[370, ]$Oe, 0.8193359, tolerance = 1e-5)
-  testthat::expect_equal(arrui_op_raw[370, ]$Oe, 0.9316406, tolerance = 1e-5)
+  arrui_op <- ip_op(arrui, compute_O = TRUE)
+  testthat::expect_equal(sum(arrui_op$O), 259.3293, tolerance = 1e-5)
+  testthat::expect_equal(sum(arrui_op$O_raw), 310.843, tolerance = 1e-5)
+  testthat::expect_equal(sum(arrui_op$Oe), 31.44434, tolerance = 1e-5)
+  testthat::expect_equal(sum(arrui_op$Oe_raw), 34.47632, tolerance = 1e-5)
+  testthat::expect_equal(arrui_op[370, ]$O, 1.169922, tolerance = 1e-5)
+  testthat::expect_equal(arrui_op[370, ]$O_raw, 2.029297, tolerance = 1e-5)
+  testthat::expect_equal(arrui_op[370, ]$Oe, 0.8193359, tolerance = 1e-5)
+  testthat::expect_equal(arrui_op[370, ]$Oe_raw, 0.9316406, tolerance = 1e-5)
 })
 
 testthat::test_that("Call to precomputed inbreeding values", {
